@@ -38,6 +38,7 @@
 #include <libanjuta/interfaces/ianjuta-environment.h>
 #include <libanjuta/interfaces/ianjuta-message-manager.h>
 #include <libanjuta/interfaces/ianjuta-document-manager.h>
+#include <libanjuta/interfaces/ianjuta-language.h>
 #include <libanjuta/interfaces/ianjuta-file-savable.h>
 #include <libanjuta/interfaces/ianjuta-indicable.h>
 #include <libanjuta/interfaces/ianjuta-preferences.h>
@@ -290,6 +291,23 @@ escape_label (const gchar *str)
 	return g_string_free (ret, FALSE);
 }
 
+static gchar*
+shell_quotef (const gchar *format,...)
+{
+	va_list args;
+	gchar *str;
+	gchar *quoted_str;
+
+	va_start (args, format);
+	str = g_strdup_vprintf (format, args);
+	va_end (args);
+
+	quoted_str = g_shell_quote (str);
+	g_free (str);
+
+	return quoted_str;
+}
+
 /* Indicator locations reported by the build */
 
 static BuildIndicatorLocation*
@@ -1334,7 +1352,7 @@ build_execute_command_in_context (BuildContext* context, GError **err)
 		ianjuta_message_view_buffer_append (context->message_view, command, NULL);
 		ianjuta_message_view_buffer_append (context->message_view, "\n", NULL);
 		g_free (command);
-	
+
 		anjuta_launcher_execute_v (context->launcher,
 		    context->program->work_dir,
 		    context->program->argv,
@@ -1723,8 +1741,6 @@ build_tarball (BasicAutotoolsPlugin *plugin)
 	return context;
 }
 
-
-
 static BuildContext*
 build_compile_file (BasicAutotoolsPlugin *plugin, const gchar *filename)
 {
@@ -1733,27 +1749,7 @@ build_compile_file (BasicAutotoolsPlugin *plugin, const gchar *filename)
 	gchar *src_dir;
 	gchar *target;
 	gchar *ext_ptr;
-	gboolean ret;
-	
-	/* FIXME: This should be configuration somewhere, eg. preferences */
-	static GHashTable *target_ext = NULL;
-	if (!target_ext)
-	{
-		target_ext = g_hash_table_new (g_str_hash, g_str_equal);
-		g_hash_table_insert (target_ext, ".c", ".o");
-		g_hash_table_insert (target_ext, ".cpp", ".o");
-		g_hash_table_insert (target_ext, ".cxx", ".o");
-		g_hash_table_insert (target_ext, ".c++", ".o");
-		g_hash_table_insert (target_ext, ".cc", ".o");
-		g_hash_table_insert (target_ext, ".y", ".o");
-		g_hash_table_insert (target_ext, ".l", ".o");
-		g_hash_table_insert (target_ext, ".in", "");
-		g_hash_table_insert (target_ext, ".in.in", ".in");
-		g_hash_table_insert (target_ext, ".la", ".la");
-		g_hash_table_insert (target_ext, ".a", ".a");
-		g_hash_table_insert (target_ext, ".so", ".so");
-		g_hash_table_insert (target_ext, ".java", ".class");
-	}
+	gboolean ret;	
 	
 	g_return_val_if_fail (filename != NULL, FALSE);
 	ret = FALSE;
@@ -1765,26 +1761,49 @@ build_compile_file (BasicAutotoolsPlugin *plugin, const gchar *filename)
 	ext_ptr = strrchr (target, '.');
 	if (ext_ptr)
 	{
-		const gchar *new_ext;
-		new_ext = g_hash_table_lookup (target_ext, ext_ptr);
-		if (new_ext)
+		GFile* file = g_file_new_for_path (filename);
+		GFileInfo* file_info = g_file_query_info (file,
+		                                          G_FILE_ATTRIBUTE_STANDARD_CONTENT_TYPE,
+		                                          G_FILE_QUERY_INFO_NONE,
+		                                          NULL,
+		                                          NULL);
+		if (file_info)
 		{
-			BuildProgram *prog;
-			
-			*ext_ptr = '\0';
-			prog = build_program_new_with_command (build_dir, "%s %s%s",
-											   CHOOSE_COMMAND (plugin, COMPILE),
-											   target, new_ext);
-			context = build_save_and_execute_command (plugin, prog, TRUE, NULL);
-			ret = TRUE;
+			const gchar *new_ext;
+			IAnjutaLanguage* langman =
+				anjuta_shell_get_interface (ANJUTA_PLUGIN (plugin)->shell,
+				                            IAnjutaLanguage,
+				                            NULL);
+			gint id = ianjuta_language_get_from_mime_type (langman,
+			                                               g_file_info_get_content_type (file_info),
+			                                               NULL);
+			DEBUG_PRINT ("Found mime-type: %s", g_file_info_get_content_type (file_info));
+			if (id > 0)
+			{
+				new_ext = ianjuta_language_get_make_target (langman, id, NULL);
+				if (new_ext)
+				{
+					BuildProgram *prog;
+
+					DEBUG_PRINT ("New extension: %s", new_ext);
+
+					*ext_ptr = '\0';
+					prog = build_program_new_with_command (build_dir, "%s %s%s",
+					                                       CHOOSE_COMMAND (plugin, COMPILE),
+					                                       target, new_ext);
+					context = build_save_and_execute_command (plugin, prog, TRUE, NULL);
+					ret = TRUE;
+				}
+			}
 		}
-	} else {
+	}
+	else {
 		/* If file has no extension, take it as target itself */
 		BuildProgram *prog;
-		
+
 		prog = build_program_new_with_command (build_dir, "%s %s",
-										   CHOOSE_COMMAND(plugin, COMPILE),
-							   			   target);
+		                                       CHOOSE_COMMAND(plugin, COMPILE),
+		                                       target);
 		context = build_save_and_execute_command (plugin, prog, TRUE, NULL);
 		ret = TRUE;
 	}
@@ -1854,14 +1873,18 @@ build_configure_dir (BasicAutotoolsPlugin *plugin, const gchar *dirname, const g
 	BuildContext *context;
 	BuildProgram *prog;
 	BuildConfigureAndBuild *pack = g_new0 (BuildConfigureAndBuild, 1);
+	gchar *quote;
 
+	quote = shell_quotef ("%s%s%s",
+		       	plugin->project_root_dir,
+		       	G_DIR_SEPARATOR_S,
+			CHOOSE_COMMAND (plugin, CONFIGURE));
 	
 	prog = build_program_new_with_command (dirname,
-										   "%s%s%s %s",
-										   plugin->project_root_dir,
-										   G_DIR_SEPARATOR_S,
-										   CHOOSE_COMMAND (plugin, CONFIGURE),
+										   "%s %s",
+										   quote,
 										   args);
+	g_free (quote);
 	pack->args = NULL;
 	pack->func = func;
 	pack->name = g_strdup (name);
@@ -1906,13 +1929,18 @@ build_configure_after_autogen (GObject *sender,
 			{
 				/* configure has not be run, run it */
 				BuildProgram *prog;
+				gchar *quote;
+
+				quote = shell_quotef ("%s%s%s",
+					     	plugin->project_root_dir,
+					       	G_DIR_SEPARATOR_S,
+					       	CHOOSE_COMMAND (plugin, CONFIGURE));
 
 				prog = build_program_new_with_command (context->program->work_dir,
-													   "%s%s%s %s",
-													   plugin->project_root_dir,
-													   G_DIR_SEPARATOR_S,
-													   CHOOSE_COMMAND (plugin, CONFIGURE),
+													   "%s %s",
+													   quote,
 													   pack != NULL ? pack->args : NULL);
+				g_free (quote);
 				build_program_set_callback (prog, build_project_configured, pack);
 		
 				build_set_command_in_context (context, prog);
@@ -1947,12 +1975,17 @@ build_generate_dir (BasicAutotoolsPlugin *plugin, const gchar *dirname, const gc
 	
 	if (directory_has_file (plugin->project_root_dir, "autogen.sh"))
 	{
+		gchar *quote;
+
+		quote = shell_quotef ("%s%s%s",
+				plugin->project_root_dir,
+			       	G_DIR_SEPARATOR_S,
+			       	CHOOSE_COMMAND (plugin, GENERATE));
 		prog = build_program_new_with_command (dirname,
-											   "%s%s%s %s",
-											   plugin->project_root_dir,
-											   G_DIR_SEPARATOR_S,
-											   CHOOSE_COMMAND (plugin, GENERATE),
+											   "%s %s",
+											   quote,
 											   args);
+		g_free (quote);
 	}
 	else
 	{
@@ -2614,16 +2647,16 @@ update_project_ui (BasicAutotoolsPlugin *bb_plugin)
 	ui = anjuta_shell_get_ui (ANJUTA_PLUGIN (bb_plugin)->shell, NULL);
 	action = anjuta_ui_get_action (ui, "ActionGroupBuild",
 								   "ActionBuildBuildProject");
-	g_object_set (G_OBJECT (action), "sensitive", has_makefile, NULL);
+	g_object_set (G_OBJECT (action), "sensitive", has_project, NULL);
 	action = anjuta_ui_get_action (ui, "ActionGroupBuild",
 								   "ActionBuildInstallProject");
-	g_object_set (G_OBJECT (action), "sensitive", has_makefile, NULL);
+	g_object_set (G_OBJECT (action), "sensitive", has_project, NULL);
 	action = anjuta_ui_get_action (ui, "ActionGroupBuild",
 								   "ActionBuildCleanProject");
-	g_object_set (G_OBJECT (action), "sensitive", has_makefile, NULL);
+	g_object_set (G_OBJECT (action), "sensitive", has_project, NULL);
 	action = anjuta_ui_get_action (ui, "ActionGroupBuild",
 								   "ActionBuildDistribution");
-	g_object_set (G_OBJECT (action), "sensitive", has_makefile, NULL);
+	g_object_set (G_OBJECT (action), "sensitive", has_project, NULL);
 	action = anjuta_ui_get_action (ui, "ActionGroupBuild",
 								   "ActionBuildConfigure");
 	g_object_set (G_OBJECT (action), "sensitive", has_project, NULL);
