@@ -41,14 +41,13 @@
 #define ANJUTA_DB_FILE	".anjuta_sym_db"
 
 /* if tables.sql changes or general db structure changes modify also the value here */
-#define SYMBOL_DB_VERSION	"228"
+#define SYMBOL_DB_VERSION	"230"
 
 #define TABLES_SQL			PACKAGE_DATA_DIR"/tables.sql"
-#define TABLES_SQL_1_TO_228	PACKAGE_DATA_DIR"/tables-from-1-to-228.sql"
 
 #define CTAGS_MARKER	"#_#\n"
 
-#define SHARED_MEMORY_PREFIX		"/dev/shm"
+#define SHARED_MEMORY_PREFIX			SYMBOL_DB_SHM
 
 #define THREADS_MAX_CONCURRENT			2
 #define TRIGGER_SIGNALS_DELAY			100
